@@ -29,7 +29,7 @@ except ImportError:
 import gi
 
 import cairo
-import mlt
+import mlt7 as mlt
 import time
 
 from gi.repository import Gtk, GObject
