@@ -27,7 +27,7 @@ import hashlib
 
 from gi.repository import Gtk, Gdk
 
-import mlt
+import mlt7 as mlt
 
 import appconsts
 import dialogutils
