@@ -28,7 +28,7 @@ import datetime
 import fnmatch
 import glob
 import hashlib
-import mlt
+import mlt7 as mlt
 import os
 from os import listdir
 from os.path import isfile, join, expanduser
