@@ -25,7 +25,7 @@ Module contains objects and methods needed to create render consumers.
 
 from gi.repository import Gdk
 
-import mlt
+import mlt7 as mlt
 import time
 import threading
 import xml.dom.minidom
