@@ -29,7 +29,7 @@ from gi.repository import Pango
 
 import cairo
 import locale
-import mlt
+import mlt7 as mlt
 import os
 import re
 import shutil
